%% Folder path

clear all
close all

% Initialize arrays and iteration values
IterCell = 0;
IterFluo1 = 0;
IterFluo2 = 0;
imageNumber = 1;
Droplet_Centroids=[];
num_img=1;

% Preallocate space in structure for speed
% 150 (=nb max of images) for main structure and 300 (=nb max of droplets) for sub-structures are assumed to be large
% enough. Otherwise increase manually these values
for i =1:150
    Time(i).Droplet(300).Timepoint = [];
    Time(i).Droplet(300).Condition = [];
    Time(i).Droplet(300).BiologicalRep = [];
    %Time(i).Droplet(300).TechnicalRep = [];
    Time(i).Droplet(300).ImageName = [];
    Time(i).Droplet(300).BeadNumber = [];
    Time(i).Droplet(300).Area = [];
    Time(i).Droplet(300).Fluo1Stats = [];
    Time(i).Droplet(300).Fluo2Stats = [];
    Time(i).Droplet(300).OverlapStats = [];
end

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'/raw_data/droplets_timepoint_images/PPU-PVE_10mM_succinate_bigger_droplets/') 

% GENERAL PARAMETERS
ch1_sensitivity = 0.25; %RFP fluorescence channel segmentation sensitivity
ch2_sensitivity = 0.25; %GFP fluorescence channel segmentation sensitivity
circle_thr = 0.94; %sensitivity threshold
min_rad = 100; % min circle radius
max_rad = 150; % max circle radius
ReduceRadii = 5; % Reduce the radii of found droplets by this many pixels to avoid overlapping area of segmented droplets
display_figure = 'no'; % set to 'yes'/'no', if you want to display/not display segmented images

%% Part 1: Image processing and segmentation of droplets and fluorescent objects. Makes a structure called 'Time'.

Timepoints=dir(strcat(Main,'T*'));
Timepoints = Timepoints(~strncmpi('.', {Timepoints.name}, 1));

    for t=1:length(Timepoints)
        Timepoint=fullfile(Main, Timepoints(t).name,'/');
        Condition = dir(Timepoint);
        Condition = Condition(~strncmpi('.', {Condition.name}, 1));

        for c=1:length(Condition)
            Cond = fullfile(Timepoint, Condition(c).name,'/')
            Replicate = dir(Cond);
            Replicate = Replicate(~strncmpi('.', {Replicate.name}, 1));

            for R=1:length(Replicate)
                Rep = fullfile(Cond, Replicate(R).name,'/')
                PhaseImgList = dir(strcat(Rep,'*BF_000.tif')); %00 for phase contrast %alternative file name : '*_ch00.tif' ; '*--C00.tif'

                for F=1:length(PhaseImgList);
                    Phase = double(imread(fullfile(Rep, PhaseImgList(F).name)));
                    Fluo1name = [PhaseImgList(F).name(1:end-10), 'RFP_000.tif']  %Replace the last 0 by 1 or 2, for fluorescence channel 1 or 2
                    Fluo1Img = double(imread(fullfile(Rep, Fluo1name)));
                    Fluo2name = [PhaseImgList(F).name(1:end-10), 'GFP_000.tif']; %Replace the last 0 by 1 or 2, for fluorescence channel 1 or 2
                    Fluo2Img = double(imread(fullfile(Rep, Fluo2name)));


                    % Flatten, normalize, increase contrast and segment Phase contrast Image
                    sigma = 30;
                    PhaseImg = imflatfield(Phase,sigma); %flattening - does not exist in vs 2016a
                    %PhaseImg = Phase;
                    NormPhase = (PhaseImg-min(PhaseImg(:)))./(max(PhaseImg(:))-min(PhaseImg(:))); %normalization
                    PhaseImg2 = imadjust(NormPhase); %increasing contrast


                    %Segment Phase contrast image
                    BW = imbinarize(PhaseImg2);
                    %Invert binarized image
                    BW2=imcomplement(BW);

                    %Detect droplets
                    [Centers,Radii] = imfindcircles(BW2,[min_rad max_rad],'ObjectPolarity','bright', 'Sensitivity',circle_thr); %Coordinates centers (x,y)
                    %[Centers,Radii] = imfindcircles(BW2,[80 120],'ObjectPolarity','bright', 'Sensitivity',0.97); %Coordinates centers (x,y)
                    %[Centers,Radii] = imfindcircles(BW2,[80 140],'ObjectPolarity','bright', 'Sensitivity',0.96); %Coordinates centers (x,y)

                    %Reduce radius to limit circles overlapping
                    Radii = Radii - ReduceRadii;

                    %Remove circles cropped by image (if circle center is at a distance from
                    %image's border smaller than its own radius)
                    for C = 1:length(Radii)
                        if Centers(C,1) < Radii(C)
                            Centers(C,:) = 0;
                            Radii(C,:) = 0;
                        else if Centers(C,2) < Radii(C)
                                Centers(C,:) = 0;
                                Radii(C,:) = 0;
                        end
                        end

                        if Centers(C,1) > 2048 - Radii(C)  %2048 corresponds here to image size on X axis
                            Centers(C,:) = 0;
                            Radii(C,:) = 0;
                        else if Centers(C,2) > 2048 - Radii(C) %2048 corresponds here to image size on Y axis
                                Centers(C,:) = 0;
                                Radii(C,:) = 0;
                        end
                        end
                    end

                    Centers2 = [];
                    CentersX = Centers(:,1);
                    CentersY = Centers(:,2);
                    Centers2(:,1) = CentersX(CentersX(:)>0);
                    Centers2(:,2) = CentersY(CentersY(:)>0);
                    Radii = Radii(Radii(:)>0);
                    Centers = Centers2;


                    %% Run through each circle

                    %Sort Radius to start with larger cells

                    [Radii, RadOrder] = sort(Radii, 'descend');
                    Centers = Centers(RadOrder,:); %Sort from the circle with the largest radius to circle with the smallest radius
                    NbBeads = length(Radii);

                    %Initialize variables

                    BeadImg = zeros(size(PhaseImg)); %Initialization of the matrix "BeadImg"

                    for D = 1:NbBeads

                        %find pixels within circle given by radius and center
                        %Get coordinates of 100 perimeter pixels based on center and radius
                        Angle = 0 : (2 * pi / 100) : (2 * pi);

                        %Each bead will be defined by 101 coordinates (x,y)
                        XPerim = Radii(D) * cos(Angle) + Centers(D,1); %Returns x-coordinate corresponding to the angles defined by "Angle"
                        YPerim = Radii(D) * sin(Angle) + Centers(D,2); %Returns y-coordinate

                        %Create matrix containing all coordinates in the square containing the circle.
                        [XGr,YGr] = meshgrid(floor(Centers(D,1)-1.1*Radii(D)) : ceil(Centers(D,1)+1.1*Radii(D)),...
                            floor(Centers(D,2)-1.1*Radii(D)) : ceil(Centers(D,2)+1.1*Radii(D))); %Creates a meshgrid of the circle

                        %Make sure XGr and YGr are not beyond the limit of the image
                        XGr(XGr<=0) = 1;
                        YGr(YGr<=0) = 1;
                        YGr(YGr>size(PhaseImg,1)) = size(PhaseImg,1);
                        XGr(XGr>size(PhaseImg,2)) = size(PhaseImg,2);

                        %Find pixels contained in the perimeter
                        InBead = inpolygon(XGr(:),YGr(:),XPerim,YPerim);

                        %Convert X-Y subscripts to indices
                        InInd = sub2ind(size(PhaseImg),YGr(InBead),XGr(InBead)); %Indices into the bead

                        %Test if center lies whitin a previously identified bead

                        if BeadImg(round(Centers(D,2)), round(Centers(D,1))) ~= 0
                            %If center is within previous identified circle: Merge with this circle
                            BeadImg(InInd) = BeadImg(round(Centers(D,2)), round(Centers(D,1)));
                        else %Otherwise create a new bead object
                            IterCell = IterCell+1;
                            BeadImg(InInd) = IterCell;
                        end
                    end


                    %% Preprocess, segment fluorescence images and collect
                    % informations for each droplets and fluorescent objects

                    %Return list of individual droplet numbers found in BeadImg
                    BeadNumber_list = unique(BeadImg);
                    BeadNumber_list = BeadNumber_list(BeadNumber_list~=0); % remove "0" from the list of droplets' numbers

                    close all
                    Fluo1Img = double(imread(fullfile(Rep, Fluo1name)));

                    %Flatten, normalize Fluo1 image background variations
                    sigma = 140;
                    Fluo1Img = imflatfield(Fluo1Img,sigma);
                    Fluo1Img_B = Fluo1Img;

                    if strcmp(Timepoints(t).name, 'T0') == 1 % T0 images segmentation
                        %Normalize the image
                        NormFluo1 = (Fluo1Img-min(Fluo1Img(:)))./(max(Fluo1Img(:))-min(Fluo1Img(:)));
                        %Remove negative values
                        NormFluo1(NormFluo1<0) = 0;
                        % Smoothen image
                        FilterDistance = 20;
                        FilterWidth = 1;
                        H1 = fspecial('gaussian',FilterDistance,FilterWidth);
                        Gauss_Fl1b_B = imfilter(NormFluo1,H1,'symmetric');

                        % Segment fluorescence 1 image
                        BWF1wholeMask  = imbinarize(Gauss_Fl1b_B,'adaptive', 'Sensitivity', 0.25);

                    else   % T24 images segmentation
                        % Smoothen image
                        FilterDistance = 20;
                        FilterWidth = 1;
                        H1 = fspecial('gaussian',FilterDistance,FilterWidth);
                        Gauss_Fl1b_B = imfilter(Fluo1Img_B,H1,'symmetric');
                        % Background subtraction using the rolling ball algorithm
                        radius = 10;
                        background1 = imopen(Gauss_Fl1b_B, strel('ball', radius, radius));
                        background1Subtracted_B = imsubtract(Gauss_Fl1b_B, background1);
                        % normalize the rolling ball-treated image to max values
                        normfl1 = (background1Subtracted_B-min(background1Subtracted_B(:)))./(max(background1Subtracted_B(:))-min(background1Subtracted_B(:)));
                        % Smoothen again
                        FilterDistance = 100;
                        FilterWidth = 1;
                        H1 = fspecial('gaussian',FilterDistance,FilterWidth);
                        Gauss_Fl1b_C = imfilter(normfl1,H1,'symmetric');

                        % Segment fluorescence 1 image
                        BWF1wholeMask  = imbinarize(Gauss_Fl1b_C,'adaptive', 'Sensitivity', 0.000025);

                    end

                    %%
                    close all
                    Fluo2Img = double(imread(fullfile(Rep, Fluo2name)));

                    %Flatten, normalize Fluo2 image background variations
                    sigma = 140;
                    Fluo2Img = imflatfield(Fluo2Img,sigma);
                    Fluo2Img_B = Fluo2Img;

                    if strcmp(Timepoints(t).name, 'T0') == 1 % T0 images segmentation
                        %Normalize the image
                        NormFluo2 = (Fluo2Img-min(Fluo2Img(:)))./(max(Fluo2Img(:))-min(Fluo2Img(:)));
                        %Remove negative values
                        NormFluo2(NormFluo2<0) = 0;
                        % Smoothen image
                        FilterDistance = 20;
                        FilterWidth = 1;
                        H1 = fspecial('gaussian',FilterDistance,FilterWidth);
                        Gauss_Fl2b_B = imfilter(NormFluo2,H1,'symmetric');

                        % Segment fluorescence 1 image
                        BWF2wholeMask  = imbinarize(Gauss_Fl2b_B,'adaptive', 'Sensitivity', 0.25);

                    else
                        %Segment the whole image to check image segmentation quality
                        FilterDistance = 20;
                        FilterWidth = 1;
                        H1 = fspecial('gaussian',FilterDistance,FilterWidth);
                        Gauss_Fl2b_B = imfilter(Fluo2Img_B,H1,'symmetric');
                        % Background subtraction using the rolling ball algorithm
                        radius = 10;
                        background2 = imopen(Gauss_Fl2b_B, strel('ball', radius, radius));
                        background2Subtracted_B = imsubtract(Gauss_Fl2b_B, background2);
                        % normalize the rolling ball-treated image to max values
                        normfl2 = (background2Subtracted_B-min(background2Subtracted_B(:)))./(max(background2Subtracted_B(:))-min(background2Subtracted_B(:)));
                        % Smoothen again
                        FilterDistance = 20;
                        FilterWidth = 1;
                        H1 = fspecial('gaussian',FilterDistance,FilterWidth);
                        Gauss_Fl2b_C = imfilter(normfl2,H1,'symmetric');

                        %Segment fluorescence 2 image
                        BWF2wholeMask  = imbinarize(Gauss_Fl2b_C,'adaptive', 'Sensitivity', 0.000025);

                    end

                    %%

                    %Loop through each droplet, make a copy of the local Fluo1 and Fluo2 images, segment and collect objects
                    for D=1:length(BeadNumber_list)


                        %Make an empty image
                        BeadImg2=zeros(size(PhaseImg));
                        %find indices of each pixel contained in currently looped droplet
                        DropInd = find(BeadImg==BeadNumber_list(D));
                        %recreate the droplet object in a separate empty matrix
                        BeadImg2(DropInd)=BeadNumber_list(D);

                        %Find droplet's centroid coordinates
                        %Return columns and rows of each pixel in droplet
                        [row,col] = find(BeadImg2);
                        %Find centroid X-coordinate
                        MaxCol=max(col);
                        MinCol=min(col);
                        %Find the column in the middle of the droplet to define X-coordinate
                        Xcentroid = MinCol+((MaxCol-MinCol)/2); % X coordinate
                        %Find centroid Y-coordinate
                        MaxRow=max(row);
                        MinRow=min(row);
                        %Find the row in the middle of the droplet to define Y-coordinate
                        Ycentroid = MinRow+((MaxRow-MinRow)/2); % Y coordinate

                        %Create Structure
                        %Save droplet's position in data set, droplet number and area

                        % timepoint number
                        Time(imageNumber).Droplet(D).Timepoint = Timepoints(t).name;
                        % Condition number
                        Time(imageNumber).Droplet(D).Condition = Condition(c).name;
                        % Biological replicate
                        Time(imageNumber).Droplet(D).BiologicalRep = Replicate(R).name;
                        % Image name
                        Time(imageNumber).Droplet(D).ImageName = PhaseImgList(F).name;
                        % Droplet number
                        Time(imageNumber).Droplet(D).BeadNumber = BeadNumber_list(D);
                        % Droplet area
                        Time(imageNumber).Droplet(D).Area = length(DropInd);
                        % X coordinate in the 1st column
                        Time(imageNumber).Droplet(D).XCentroid = Xcentroid;
                        % Y coordinate in the 2nd column
                        Time(imageNumber).Droplet(D).YCentroid = Ycentroid;


                        %% make a copy of fluorescence 1 image with the single bead

                        BWF1_Droplet = BWF1wholeMask;
                        BWF1_Droplet(BeadImg2==0)=0;%Remove all signal outside of currently looped droplet

                        %Calculate properties of all objects within the droplet
                        CC = bwconncomp(BWF1_Droplet);
                        Fluo1Stats = regionprops(CC, Fluo1Img, 'Area','PixelIdxList', 'MeanIntensity', 'Centroid');


                        %% make a copy of fluorescence 2 image with the single bead

                        BWF2_Droplet = BWF2wholeMask;
                        BWF2_Droplet(BeadImg2==0)=0;%Remove all signal outside of currently looped droplet

                        %Calculate properties of all objects within the droplet
                        CC2 = bwconncomp(BWF2_Droplet);
                        Fluo2Stats = regionprops(CC2, Fluo2Img, 'Area','PixelIdxList', 'MeanIntensity', 'Centroid');


                        %% Collect all Fluorescence 1 objects

                        % Collect whole droplet fluorescence 1
                        Time(imageNumber).Droplet(D).TotalDropletFluo1 = sum(Fluo1Img(DropInd));

                        for S = 1:length(Fluo1Stats)
                            %Save object area
                            Time(imageNumber).Droplet(D).Fluo1Stats(S).Area  = Fluo1Stats(S).Area;
                            Time(imageNumber).Droplet(D).Fluo1Stats(S).MeanIntensity  = Fluo1Stats(S).MeanIntensity;
                            Time(imageNumber).Droplet(D).Fluo1Stats(S).CentroidX= Fluo1Stats(S).Centroid(1);
                            Time(imageNumber).Droplet(D).Fluo1Stats(S).CentroidY= Fluo1Stats(S).Centroid(2);
                            Time(imageNumber).Droplet(D).Fluo1Stats(S).TotIntensity = Fluo1Stats(S).Area.*Fluo1Stats(S).MeanIntensity;
                            Time(imageNumber).Droplet(D).Fluo1Stats(S).ObjectPixelList = Fluo1Stats(S).PixelIdxList;

                        end
                        %% Collect all Fluorescence 2 objects

                        % Collect whole droplet fluorescence 2
                        Time(imageNumber).Droplet(D).TotalDropletFluo2 = sum(Fluo2Img(DropInd));

                        for k=1:length(Fluo2Stats)

                            Time(imageNumber).Droplet(D).Fluo2Stats(k).Area = Fluo2Stats(k).Area;
                            Time(imageNumber).Droplet(D).Fluo2Stats(k).MeanIntensity  = Fluo2Stats(k).MeanIntensity;
                            Time(imageNumber).Droplet(D).Fluo2Stats(k).CentroidX  = Fluo2Stats(k).Centroid(1);
                            Time(imageNumber).Droplet(D).Fluo2Stats(k).CentroidY  = Fluo2Stats(k).Centroid(2);
                            Time(imageNumber).Droplet(D).Fluo2Stats(k).ObjectPixelList = Fluo2Stats(k).PixelIdxList;
                            Time(imageNumber).Droplet(D).Fluo2Stats(k).TotIntensity = Fluo2Stats(k).Area.*Fluo2Stats(k).MeanIntensity;

                            %% Calculate overlap of objects

                            %Find pixels belonging to Fluo2 object which are Fluo1
                            OverlapPixels = find(BWF1_Droplet(Fluo2Stats(k).PixelIdxList)==1);
                            Time(imageNumber).Droplet(D).OverlapStats(k).Fluo1_OverlapArea = length(OverlapPixels);
                            Time(imageNumber).Droplet(D).OverlapStats(k).Fluo1Coloc = length(OverlapPixels)/Fluo2Stats(k).Area;
                            Time(imageNumber).Droplet(D).OverlapStats(k).Fluo2ExlcCellArea = Fluo2Stats(k).Area - length(OverlapPixels);
                        end

                        BeadImg2=[];%empty the BeadImg2 droplet mask for the next droplet


                    end

                    imageNumber = imageNumber + 1;

                    %% Display circles, Phase contrast image, droplets and segmentation masks

                    if strcmp(display_figure,'yes')
                        figure(num_img)
                        tiledlayout(2,2)
                        nexttile
                        imagesc(PhaseImg)
                        hold on
                        viscircles(Centers, Radii,'EdgeColor','b');
                        hold off
                        nexttile
                        imagesc(BeadImg)
                        nexttile(3)
                        imagesc(BWF1wholeMask)
                        hold on
                        viscircles(Centers, Radii,'EdgeColor','b');
                        hold off
                        title('Fluorescence 1 segmentation')
                        nexttile(4)
                        imagesc(BWF2wholeMask)
                        hold on
                        viscircles(Centers, Radii,'EdgeColor','b');
                        hold off
                        title('Fluorescence 2 segmentation')
                        %set figure window size
                        pos = [0, 400, 1200, 1000]; % => the last two values corresponds to the window size
                        set(gcf, 'Position', pos);
                        num_img = num_img + 1;
                    end


                end

            end

        end
    end




    % Find and delete empty pre-allocated sub-structrures in Time structure
    id = 1;
    for c = 1:length(Time)
        if isempty(Time(c).Droplet(1).ImageName) == 1
            emptyIndex(id,1) = c;
            id=id+1;
        end
    end
    Time(emptyIndex) = [];


    %% Part 2: Filter object areas that are below the defined thresholds,
    % and filter fluo contamination (Fluo1 in Fluo2) based on overlap stat and
    % mean pixel intensity of objects

    % close all
    %
    % %Visualize objects fluorescence 2 and fluo overlapping area in one image
    % ListObj3 = struct2table([Time(1).Droplet]); % select only one image in the Time structure
    % ListObj3 = table2struct(ListObj3(:,{'Fluo2Stats','OverlapStats'}));
    % Fluo2 = struct2table([ListObj3(:).Fluo2Stats]);
    % Overlap = struct2table([ListObj3(:).OverlapStats]);
    % ListObj3 = [Fluo2,Overlap]; % To get a table that contains only Fluo2 obj stats with corresponding overlap stats
    %
    % figure
    % scatter(ListObj3.Fluo1Coloc, ListObj3.MeanIntensity)
    %
    %
    % % Creat empty mask image to display filtered objects based on fluo overlap
    % % and mean fluo2 intensity
    % MeanIntensity = ListObj3.MeanIntensity;
    % Fluo1Coloc = ListObj3.Fluo1Coloc;
    %
    % ind_1 = find(MeanIntensity <= 0.00035); %find objects with low mean intensity
    % ind_2 = find(Fluo1Coloc == 1); %find objecdts completely overlapping with Fluo1
    % ind = intersect(ind_1, ind_2); %get indices of objects respecting both conditions
    %
    % Table_fin = ListObj3;
    % Table_fin(ind,:) = [];
    %
    %
    % FilteredImg = zeros(size(BeadImg));
    % PixelList = table2struct(Table_fin);
    % PixelList = vertcat(PixelList(:).ObjectPixelList); % get list of all pixels index of objects
    % FilteredImg(PixelList) = 1; % display filtered objects
    %
    % figure
    % imagesc(FilteredImg)
    % hold on
    % viscircles(Centers, Radii,'EdgeColor','b');
    % hold off
    % title('Fluorescence 2 - filtered')
    %
    %
    % figure
    % imagesc(BWF2wholeMask)
    % hold on
    % viscircles(Centers, Radii,'EdgeColor','b');
    % hold off
    % title('Fluorescence 2 segmentation')


% Filter objects 

% Set filtering thresholds for T=0h or T=24h images
Area_thr_fl1_t0 = 5; % set the area threshold here (fluo 1)
Area_thr_fl2_t0 = 5; % set the area threshold here (fluo 2)
Area_thr_fl1_t24 = 70; % set the area threshold here (fluo 1)
Area_thr_fl2_t24 = 10; % set the area threshold here (fluo 2)
% Mean_Int_fl2 = 0.00035; % set mean intensity threshold (to remove fluo 1 obj contaminating in fluo 2 channel)

Time_filtered = Time;

for F=1:length(Time_filtered)
    for D=1:length(Time_filtered(F).Droplet)

        %remove filtered objects and associated overlap stats from Time_filtered structure
        if isempty(Time_filtered(F).Droplet(D).Fluo1Stats) == 0
            if strcmp(Time_filtered(F).Droplet(D).Timepoint, 'T0') == 1 % apply different object size thresholds for t=0h images
            Time_filtered(F).Droplet(D).Fluo1Stats([Time_filtered(F).Droplet(D).Fluo1Stats.Area] < Area_thr_fl1_t0) = [];
            else
            Time_filtered(F).Droplet(D).Fluo1Stats([Time_filtered(F).Droplet(D).Fluo1Stats.Area] < Area_thr_fl1_t24) = [];
            end
        end
        if isempty(Time_filtered(F).Droplet(D).Fluo2Stats) == 0
            if strcmp(Time_filtered(F).Droplet(D).Timepoint, 'T0') == 1 % apply different object size thresholds for t=0h images
            Time_filtered(F).Droplet(D).Fluo2Stats([Time_filtered(F).Droplet(D).Fluo2Stats.Area] < Area_thr_fl2_t0) = []; %remove obj bellow area thr
            else
            Time_filtered(F).Droplet(D).Fluo2Stats([Time_filtered(F).Droplet(D).Fluo2Stats.Area] < Area_thr_fl2_t24) = []; %remove obj bellow area thr
            end
        end
        

        if length(Time_filtered(F).Droplet(D).Fluo1Stats) == 0
            Time_filtered(F).Droplet(D).Fluo1Stats = [];
        end
        if length(Time_filtered(F).Droplet(D).Fluo2Stats) == 0
            Time_filtered(F).Droplet(D).Fluo2Stats = [];
        end        
        
    end
end

% sum productivity per droplet and add to the 'Time' structure array

for F=1:length(Time_filtered)
    for D=1:length(Time_filtered(F).Droplet)
        
        if isempty(Time_filtered(F).Droplet(D).Fluo1Stats)==1
            Time_filtered(F).Droplet(D).Fluo1Sum = 0;
            Time_filtered(F).Droplet(D).NumberFluo1objects = 0;
            Time_filtered(F).Droplet(D).TotFL1Area = 0;
        else
            Time_filtered(F).Droplet(D).Fluo1Sum=sum(vertcat(Time_filtered(F).Droplet(D).Fluo1Stats(:).TotIntensity));
            Time_filtered(F).Droplet(D).NumberFluo1objects=length(Time_filtered(F).Droplet(D).Fluo1Stats); %Number of fluorescent1 objects
            Time_filtered(F).Droplet(D).TotFL1Area=sum(vertcat(Time_filtered(F).Droplet(D).Fluo1Stats(:).Area)); %in pixels
        end
        
        if isempty(Time_filtered(F).Droplet(D).Fluo2Stats)==1
            Time_filtered(F).Droplet(D).Fluo2Sum = 0;
            Time_filtered(F).Droplet(D).NumberFluo2objects = 0;
            Time_filtered(F).Droplet(D).TotFL2Area = 0;
        else
            Time_filtered(F).Droplet(D).Fluo2Sum=sum(vertcat(Time_filtered(F).Droplet(D).Fluo2Stats(:).TotIntensity));
            Time_filtered(F).Droplet(D).NumberFluo2objects=length(Time_filtered(F).Droplet(D).Fluo2Stats); %Number of fluorescent2 objects
            Time_filtered(F).Droplet(D).TotFL2Area=sum(vertcat(Time_filtered(F).Droplet(D).Fluo2Stats(:).Area)); %in pixels
        end
        
        if length(Time_filtered(F).Droplet(D).OverlapStats)==0
            Time_filtered(F).Droplet(D).OverlapArea = 0;
            Time_filtered(F).Droplet(D).ProportionFl1AreaOverlap = 0;
            Time_filtered(F).Droplet(D).ProportionFl2AreaOverlap = 0;
        else
            Time_filtered(F).Droplet(D).OverlapArea=sum(vertcat(Time_filtered(F).Droplet(D).OverlapStats(:).Fluo1_OverlapArea)); %in pixels
            Time_filtered(F).Droplet(D).ProportionFl1AreaOverlap = Time_filtered(F).Droplet(D).OverlapArea/Time_filtered(F).Droplet(D).TotFL1Area;
            Time_filtered(F).Droplet(D).ProportionFl2AreaOverlap = Time_filtered(F).Droplet(D).OverlapArea/Time_filtered(F).Droplet(D).TotFL2Area;
        end
        
    end
end



%% Make a per droplet summary table for further data processing

combined=[Time_filtered(:).Droplet]; %to combine all time fields into one structure
tf=struct2table(combined); %to transform the structure array to a table
tf = removevars(tf,{'Fluo1Stats','Fluo2Stats','OverlapStats'}); %delete variables with the Stats

% delete empty droplet rows in table (= extra pre-allocated space)
loc=cellfun('isempty', tf{:,'Timepoint'} );
tf(loc,:)=[];


%% Save and export table (.csv file)

% Remove the last part after the last '/' (script file name)
result_path = strcat(Currentdir, 'Figure8&S12-S14/results_plots/');
% save droplets data frame
writetable(tf,fullfile(result_path,'droplet_results_80µmdrop_doubled_founder_pop.csv'),'WriteRowNames',true);




