
rm(list = ls())

library(ggExtra)
library(ggplot2)
library(tidyverse)
library(dplyr)
library(patchwork)
library(data.table)
library(ggpubr)
library(sf)
library(EnvStats)
# install.packages("ggpubr")


      ############## DROPLETS IMAGES - TIMEPOINTS ANALYSIS ##############


### ==========================================================
###                     Import data frame 
### ==========================================================


######## set, working directory ########
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()



### load the three tables for PPU/PVE on succinate in various droplets sizes or founder population sizes
DropletsF.40.small = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/droplet_results_40µmdrop.csv"), sep = "," , header = T)
DropletsF.80.small = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/droplet_results_80µmdrop.csv"), sep = "," , header = T)
DropletsF.80.large = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/droplet_results_80µmdrop_doubled_founder_pop.csv"), sep = "," , header = T)


### =========================
###      POST PROCESSING
### =========================

### Add 'mono/mix' column

DropletsF.40.small <- DropletsF.40.small %>% 
  mutate(Condition2 = case_when(
    Condition == 'C21' ~ 'MEDIUM',
    Condition == 'Ppu' ~ 'PPU',
    Condition == 'Pve' ~ 'PVE',
    Condition == 'PvePpu' ~ 'MIX'
      ))
DropletsF.40.small$Condition = DropletsF.40.small$Condition2 ; DropletsF.40.small$Condition2 <- NULL
DropletsF.40.small <- DropletsF.40.small %>% 
  mutate(NbSpecies = case_when(
    Condition == 'MIX' & Fluo1Sum == 0 & Fluo2Sum > 0 | Condition == 'MIX' & Fluo1Sum > 0 & Fluo2Sum == 0 ~ "solo", 
    Fluo1Sum == 0 & Fluo2Sum == 0 ~ "medium",
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "mix",
    Condition == 'PPU' ~ 'mono',
    Condition == 'PVE' ~ 'mono',
  )) %>% 
  ### Add 'Species' column
  mutate(Species = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 ~ 'PPU',
    Fluo1Sum > 0 & Fluo2Sum == 0 ~ 'PVE',
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "PPU PVE"
  )) %>%
  mutate(factor = fct_relevel(NbSpecies, "mono", "solo","mix","medium")) %>%  # Add a 'factor' column to plot mono-culture before mix-culture
  mutate(second.condition = '40µm small')


DropletsF.80.small <- DropletsF.80.small %>% 
  mutate(NbSpecies = case_when(
    Condition == 'MIX' & Fluo1Sum == 0 & Fluo2Sum > 0 | Condition == 'MIX' & Fluo1Sum > 0 & Fluo2Sum == 0 ~ "solo", 
    Fluo1Sum == 0 & Fluo2Sum == 0 ~ "medium",
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "mix",
    Condition == 'PPU' ~ 'mono',
    Condition == 'PVE' ~ 'mono',
  )) %>% 
  ### Add 'Species' column
  mutate(Species = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 ~ 'PPU',
    Fluo1Sum > 0 & Fluo2Sum == 0 ~ 'PVE',
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "PPU PVE"
  )) %>%
  mutate(factor = fct_relevel(NbSpecies, "mono", "solo","mix","medium")) %>%  # Add a 'factor' column to plot mono-culture before mix-culture
  mutate(second.condition = '80µm small')


DropletsF.80.large <- DropletsF.80.large %>% 
  mutate(NbSpecies = case_when(
    Condition == 'MIX' & Fluo1Sum == 0 & Fluo2Sum > 0 | Condition == 'MIX' & Fluo1Sum > 0 & Fluo2Sum == 0 ~ "solo", 
    Fluo1Sum == 0 & Fluo2Sum == 0 ~ "medium",
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "mix",
    Condition == 'PPU' ~ 'mono',
    Condition == 'PVE' ~ 'mono',
  )) %>% 
  ### Add 'Species' column
  mutate(Species = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 ~ 'PPU',
    Fluo1Sum > 0 & Fluo2Sum == 0 ~ 'PVE',
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "PPU PVE"
  )) %>%
  mutate(factor = fct_relevel(NbSpecies, "mono", "solo","mix","medium")) %>%# Add a 'factor' column to plot mono-culture before mix-culture
  mutate(second.condition = '80µm large')


### Normalize both fluorescent signals based on median signal in mono-culture droplets

# Set productivity thresholds filter out 'non-growing' droplets in mono-cultures
# when estimating the median productivity in mono-culture

threshold_PVE_40µm <- 1
threshold_PPU_40µm <- 0.2

threshold_PVE_80µm <- 0.1e+07
threshold_PPU_80µm <- 2.5e+06

### 40 µm droplets - small founder population sizes
DropletsF2 <- DropletsF.40.small
threshold_PPU <- threshold_PPU_40µm
threshold_PVE <- threshold_PVE_40µm
# Call and run the sub-script
source(paste0(getwd(), '/Figure8&S12-S14/scripts/sub_scripts/normalize_AF_productivities.R'))
DropletsF.40.small <- DropletsF2

### 80 µm droplets - small founder population sizes
DropletsF2 <- DropletsF.80.small
threshold_PPU <- threshold_PPU_80µm
threshold_PVE <- threshold_PVE_80µm
# Call and run the sub-script
source(paste0(getwd(), '/Figure8&S12-S14/scripts/sub_scripts/normalize_AF_productivities.R'))
DropletsF.80.small <- DropletsF2

### 80 µm droplets - larger founder population sizes
DropletsF2 <- DropletsF.80.large
threshold_PPU <- threshold_PPU_80µm
threshold_PVE <- threshold_PVE_80µm
# Call and run the sub-script
source(paste0(getwd(), '/Figure8&S12-S14/scripts/sub_scripts/normalize_AF_productivities.R'))
DropletsF.80.large <- DropletsF2


# Add tech rep column if not already existing
DropletsF.80.small <- DropletsF.80.small %>% 
  mutate(TechnicalRep = 'r1')
DropletsF.80.large <- DropletsF.80.large %>% 
  mutate(TechnicalRep = 'r1')

# keep only certain columns in the same order before merging the three data frames
DropletsF.40.small2 <- DropletsF.40.small %>% 
  select(second.condition, Timepoint, Condition, BiologicalRep, TechnicalRep, ImageName, Area, NbSpecies, Species, factor, Fluo1Sum, Fluo2Sum, norm_fluo1, norm_fluo2, NumberFluo1objects, NumberFluo2objects)
DropletsF.80.small2 <- DropletsF.80.small %>% 
  select(second.condition, Timepoint, Condition, BiologicalRep, TechnicalRep, ImageName, Area, NbSpecies, Species, factor, Fluo1Sum, Fluo2Sum, norm_fluo1, norm_fluo2, NumberFluo1objects, NumberFluo2objects)
DropletsF.80.large2 <- DropletsF.80.large %>% 
  select(second.condition, Timepoint, Condition, BiologicalRep, TechnicalRep, ImageName, Area, NbSpecies, Species, factor, Fluo1Sum, Fluo2Sum, norm_fluo1, norm_fluo2, NumberFluo1objects, NumberFluo2objects)

# Combine data frames
DropletsF <- rbind(DropletsF.40.small2, DropletsF.80.small2, DropletsF.80.large2)
DropletsF <- DropletsF %>%
  mutate(factor2 = fct_relevel(second.condition, "40µm small", "80µm small","80µm large")) # Add a 'factor' column to plot mono-culture before mix-culture

# Add a radius column (in pixels, deduced from the Area)
DropletsF$Radii <- sqrt(DropletsF$Area/pi)


### ==============================================
###       Starting cell numbers distribution
### ==============================================


initial_cell_nb <- DropletsF %>% filter(Timepoint == 'T0')

### Mean starting cell number

# all droplets
means.startcell.all.drop <- initial_cell_nb %>%
  filter(Condition == 'MIX') %>%
  group_by(factor2, BiologicalRep) %>%
  summarise(mean_ppu_nb = mean(NumberFluo2objects),
            mean_pve_nb = mean(NumberFluo1objects),
            mean_drop_area = mean(Area))

# mix droplets only
means.startcell.mix.drop <- initial_cell_nb %>%
  filter(Condition == 'MIX', Species == 'PPU PVE') %>%
  group_by(factor2, BiologicalRep) %>%
  summarise(mean_ppu_nb = mean(NumberFluo2objects),
            mean_pve_nb = mean(NumberFluo1objects),
            mean_drop_area = mean(Area))

# save table
write.csv(means.startcell.all.drop, paste0(getwd(), '/Figure8&S12-S14/results_plots/starting_cell_nb_all_droplets.csv'))
write.csv(means.startcell.mix.drop, paste0(getwd(), '/Figure8&S12-S14/results_plots/starting_cell_nb_mix_dropletsonly.csv'))

# Co-culture droplets
starting_cell_hist <- ggplot(initial_cell_nb %>% filter(Condition == 'MIX'), aes(x = NumberFluo2objects))+
  geom_histogram(aes(y = ..density..), binwidth = 1, color = 'Darkgreen', fill = 'darkseagreen3', alpha = 0.7 )+
  facet_grid(factor2 ~ BiologicalRep)+
  ggtitle('Starting P. putida cell distribution in mixed emulsion (OD=0.01)')+
  xlim(-1,20)+
  theme_bw()+
  geom_vline(data = means.startcell.all.drop, aes(xintercept = mean_ppu_nb), linetype = "dashed", color = "blue", size = 1)+
  labs(x = 'Number P. putida cells per droplet', y = 'Density', title = 'P. putida cells distribution in co-culture droplets (t = 0 h)')+
  ggplot(initial_cell_nb %>% filter(Condition == 'MIX'), aes(x = NumberFluo1objects))+
  facet_grid(factor2 ~ BiologicalRep)+
  geom_histogram(aes(y = ..density..), binwidth = 1, color = 'Magenta3', fill = 'plum2', alpha = 0.7 )+
  geom_vline(data = means.startcell.all.drop, aes(xintercept = mean_pve_nb), linetype = "dashed", color = "blue", size = 1)+
  labs(x = 'Number P. veronii cells per droplet', y = 'Density', title = 'P. veronii cells distribution in co-culture droplets (t = 0 h)')+
  xlim(-1,20) +
  theme_bw() ; starting_cell_hist

# save plots
pdf(paste0(getwd(),'/Figure8&S12-S14/results_plots/FigS13_A_B.pdf'), width=8, height=5)
starting_cell_hist
dev.off()


### Droplets radii

# all droplets
means.all.drop.radii <- initial_cell_nb %>%
  filter(Condition == 'MIX') %>%
  group_by(factor2, BiologicalRep) %>%
  summarise(mean_drop_radii = mean(Radii))


# Calculate the mean of observed variances for each condition
mean_data <- aggregate(mean_drop_radii ~ factor2, data = means.all.drop.radii, FUN = mean)
stderr_data <- aggregate(mean_drop_radii ~ factor2, data = means.all.drop.radii, FUN = sd )
mean_stderr_data <- merge(mean_data, stderr_data, by = c("factor2"))
# save table
write.csv(mean_stderr_data, paste0(getwd(), '/Figure8&S12-S14/results_plots/starting_droplets_radii.csv'))


# Create a barplot
drop.rad <- ggplot(mean_stderr_data, aes(x = factor2, y = mean_drop_radii.x)) +
  geom_col(fill = 'skyblue4', width = 0.7) +
  geom_errorbar(aes(ymin = mean_drop_radii.x - mean_drop_radii.y, ymax = mean_drop_radii.x + mean_drop_radii.y),
                position = position_dodge(width = 0.9), width = 0.25) +
  labs(x = "Starting condition", y = "Mean droplets radii (pixels)", fill = 'Starting cell distribution') +
  ggtitle("Droplets radii (t = 0 h)") +
  theme_bw(); drop.rad

# save plots
pdf(paste0(getwd(),'/Figure8&S12-S14/results_plots/FigS13_C.pdf'), width=4, height=4)
drop.rad
dev.off()



### =====================================================================
###           PRODUCTIVITIES, MONO AND MIX - SIGNAL NORMALIZED
### =====================================================================


# Relative normalized biomass
relative.norm <- ggplot(DropletsF %>% filter(Timepoint == 'T24', NbSpecies == 'mix', Condition == 'MIX'),
                        aes(x = factor2, y = norm_fluo1/(norm_fluo1+norm_fluo2))) +
  geom_jitter(size = 1, alpha = 0.2, color = 'Magenta4')+ # 
  geom_violin(draw_quantiles = c(0.25,0.5,0.75), alpha = 0.1)+
  theme_bw()+
#  theme(axis.text.x = element_text(angle = 45, hjust = 1))+
  labs(x = 'Starting condition', y = 'Relative P.veronii biomass (normalized AF)', title = 'Mix droplets (t = 24 h)'); relative.norm

# save plots
pdf(paste0(getwd(),'/Figure8&S12-S14/results_plots/Fig8_H.pdf'), width=2.85 , height=3)
relative.norm
dev.off()


# Mix productivities - PVE vs PPU
norm.mix.all <- ggplot(DropletsF %>% filter(Timepoint == 'T24', NbSpecies == 'mix', Condition == 'MIX'),
       aes(x = sqrt(norm_fluo2), y = sqrt(norm_fluo1), color = BiologicalRep)) +
  facet_wrap(~factor2)+
  xlim(0,2)+
  ylim(0,2)+
  geom_jitter(size = 0.8, alpha = 0.7)+
  geom_abline(slope = 1, intercept = 0, color = "black", linetype = "dashed", size = 0.75)+
  theme_bw()+
  #  theme(axis.text.x = element_text(angle = 45, hjust = 1))+
  labs(x = 'PPU median-normalized productivity', y = 'PVE median-normalized productivity', title = 'Mix droplets (t = 24 h)'); norm.mix.all

# save plots
pdf(paste0(getwd(),'/Figure8&S12-S14/results_plots/FigS14.pdf'), width=8.85, height=3)
norm.mix.all
dev.off()

### =====================================================================
###                           Variance in data
### =====================================================================


### Pairwise variance comparison - pooled replicates droplets growth distributions
var.data <- DropletsF %>% filter(Timepoint == 'T24', Condition == 'MIX', NbSpecies == 'mix')
var.data$relative.norm.pve <- var.data$norm_fluo1/(var.data$norm_fluo1 + var.data$norm_fluo2)

names(var.data)

# measure overall variance - pooled replicates
var.mixgrowth.all.drop <- var.data %>%
  group_by(factor2) %>%
  summarise(var.pve.relative.biomass = var(relative.norm.pve))

# Create a barplot
pve.var2 <- ggplot(var.mixgrowth.all.drop, aes(x = factor2, y = var.pve.relative.biomass)) +
  geom_col(fill = 'skyblue4', width = 0.7) +
  ylim(0, 0.1) +
  labs(x = "Starting condition", y = "Var(PVE relative biomass)", fill = 'Starting cell distribution') +
  ggtitle("Variance of PVE relative biomass (pooled replicates)") +
  theme_bw(); pve.var2

### save plot
pdf(paste0(getwd(),'/Figure8&S12-S14/results_plots/Fig8_I.pdf'), width=3 , height=3.5)
pve.var2
dev.off()


# groups to compare
var.data.1_2 <- var.data %>% filter(second.condition == '40µm small' | second.condition == '80µm small')
var.data.1_3 <- var.data %>% filter(second.condition == '40µm small' | second.condition == '80µm large')
var.data.2_3 <- var.data %>% filter(second.condition == '80µm small' | second.condition == '80µm large')

# Pairwise variance comparison test
fligner.test(relative.norm.pve ~ second.condition, data = var.data.1_2) # 40µm small vs 80µm small
fligner.test(relative.norm.pve ~ second.condition, data = var.data.1_3) # 40µm small vs 80µm large
fligner.test(relative.norm.pve ~ second.condition, data = var.data.2_3) # 80µm small vs 80µm large
# Adjust p-values (Bon Ferroni method)
p_values <- c(0.0004981, 4.017e-11, 3.656e-06) # p-values obtained above
adjusted_p_values <- p.adjust(p_values, method = "bonferroni"); adjusted_p_values






