
rm(list = ls())

# install.packages()  #### to install new packages before opening them with 'library()'
library(ggplot2)
library(tidyverse)
library(patchwork)
library(data.table)
library(ggpubr)
library(dplyr)
library(ggExtra)
library(EnvStats)


      ############## Flow-cytometry counting - droplets and 96 well plates ##############
                       ##############  SUCCINATE 10mM  ##############


### ======================================================================
###  IMPORT DROPLETS DATA FRAMES - PROPORTION OF EMPTY/NON EMPTY DROPLETS
### ======================================================================


# Set working directory to location of script file (main folder)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # location of script file (main folder)
getwd()

mainpath <- getwd()
# Split the path by '/'
pathComponents <- unlist(strsplit(mainpath, "/"))
# Get the length of the path components
numComponents <- length(pathComponents)
# Reconstruct the path up to the 3rd '/' from the end
# Note: We use paste with collapse to reconstruct the path
outputPath <- paste(pathComponents[1:(numComponents - 2)], collapse = "/")
setwd(outputPath); getwd()


# import droplet data frame
DropletsF = read.table(paste0(getwd(),"/Figure8&S12-S14/results_plots/droplet_results_80µmdrop_doubled_founder_pop.csv"), sep = "," , header = T)
summary(DropletsF)

# Set the path to the sub-script that will use the loaded DropletsF data frame
# (result of the analysis of droplets microscopy images) to assess the 
# proportions of empty/non-empty droplets. These proportions will 
# be used to adjust the measured concentration of cells by flow cytometry on
# the total volume of fused droplets.
script_path <- paste0(getwd(),"/Figure8&S12-S14/scripts/sub_scripts/proportion_non_empty_droplets_PPU_PVE_large_droplets_higher_density.R")
# Call and run the sub-script
source(script_path)


### ======================================================================
###          IMPORT FLOW CYTOMETRY DATA FRAME + POST PROCESSING
### ======================================================================


# Import FC counting table
fc_table <- read.table(paste0(getwd(),"/Raw_data/flow_cytometry/PPU-PVE_10mM succinate_big_droplets_and_start_pop/fc_counting.csv"), sep = ";" , header = T)
# Import well names table
well_names <- read.table(paste0(getwd(),"/Raw_data/flow_cytometry/PPU-PVE_10mM succinate_big_droplets_and_start_pop/microplate_well_annotation.csv"), sep = ";" , header = T)

# post processing script
script_path2 <- paste0(getwd(),"/Figure8&S12-S14/scripts/sub_scripts/fc_counting_post_processing_PPU_PVE_large_droplets_higher_density.R")

# Call and run the sub-script
source(script_path2)


# Calculate means cell concentrations per technical replicate
mean.tech.rep <- cell_conc %>%
  group_by(Culture, Condition, BioRep, TechRep, DilutionFactor) %>%
  summarise(across(
    c(CellConcentration.GFP, CellConcentration.MCH),
    mean,
    .names = "Mean.{col}"
  ))

# Calculate means cell concentrations per biological replicate
mean.bio.rep <- mean.tech.rep %>%
  group_by(Culture, Condition, BioRep, DilutionFactor) %>%
  summarise(across(
    c(Mean.CellConcentration.GFP, Mean.CellConcentration.MCH),
    mean,
    .names = "Biorep.{col}"
  ))

# ratios in mix - droplets and plate
mean.bio.rep$ratio.gfp.on.mch <- mean.bio.rep$Biorep.Mean.CellConcentration.GFP/mean.bio.rep$Biorep.Mean.CellConcentration.MCH
# Save per bio rep ratios table
write.csv(mean.bio.rep, paste0(getwd(),'/Figure8&S12-S14/results_plots/fc_counts_bigdroplets_bigpop_ratios_table.csv'), row.names = FALSE)







