function [Tot_nb_Cells_Evol, Abund_sim_PVE, Abund_sim_PPU, Props_sim_PVE, Nb_Cells_Droplet] = Main_Fun_Droplets_Mult_Cells(parameters_distr, cell_distribution, probability_dead_ppu, probability_dead_pve, vol_droplets, Mass_cell, nb_droplet, mu_droplet, k1_Pve, k2_Pve, k3_Pve, k1_Ppu, k2_Ppu, k3_Ppu, Threshold, Lag_Time_Pve, Lag_Time_Ppu, mean_R_0, sigma_R_0, Time_step, Name_file, save_data)    
   

    opts_1 = odeset('RelTol',1e-9,'AbsTol',1e-10);%,'NonNegative',1:11); %To smooth the curves obtained using ode45.

    tspan = [min(Time_step), max(Time_step)];

    %Initialization of final results
    Abund_sim_PVE = zeros(nb_droplet, 1);
    Abund_sim_PPU = zeros(nb_droplet, 1);
    Fin_W1_used = zeros(nb_droplet, 1);
    Fin_W2_used = zeros(nb_droplet, 1);
    Props_sim_PVE = zeros(1, nb_droplet);
    Tot_nb_Cells_Evol = zeros(length(Time_step), nb_droplet);
    [PVE_fin_abs, PPU_fin_abs, W1_tot_used, W2_tot_used] = deal(zeros(1, nb_droplet));
    Nb_Cells_Droplet = zeros(nb_droplet, 2);
    num_fig = 1;
    n_iter = nb_droplet; %The number of iteration corresponds to the number of beads. Can be modified if we want several replicates by beads for instance.
    %Initialization of the characteristics of each bead and cells inside.
    % Distribution of starting cells across droplets
    if strcmp(cell_distribution ,'poisson')
    nb_PVE_cells = poissrnd(mu_droplet(1), nb_droplet, 1);
    nb_PPU_cells = poissrnd(mu_droplet(1), nb_droplet, 1);
    end
    if strcmp(cell_distribution ,'uniform')
    nb_PVE_cells = repmat(mu_droplet(1), nb_droplet, 1); % uniform distribution of PVE cells
    nb_PPU_cells = repmat(mu_droplet(1), nb_droplet, 1); % uniform distribution of PPU cells
    end

    kappa_2 = [normrnd(k2_Pve(1), k2_Pve(2),  1, n_iter);...
        normrnd(k2_Ppu(1), k2_Ppu(2),  1, n_iter)];
    kappa_3 = [normrnd(k3_Pve(1), k3_Pve(2),  1, n_iter);...;...
        normrnd(k3_Ppu(1), k3_Ppu(2),  1, n_iter)];%Unit h^(-1)
    kappa_1_temp = [normrnd(k1_Pve(1), k1_Pve(2),  1, n_iter);...
        normrnd(k1_Ppu(1), k1_Ppu(2),  1, n_iter)];
    Tab_output = {};
    Tab_WastUsed = {};
    for i = 1:n_iter
        mean_R_0_temp = normrnd(mean_R_0, sigma_R_0);
        vol_beads_temp = normrnd(vol_droplets(1), vol_droplets(2));%Variation of the bead volume, replace by observed values
%         LT_Pve = normrnd(Lag_Time_Pve(1), Lag_Time_Pve(2),1, nb_PVE_cells(i));
%         LT_Ppu = normrnd(Lag_Time_Ppu(1), Lag_Time_Ppu(2), 1, nb_PPU_cells(i));
        Mass_Cell_Pve = normrnd(Mass_cell(1, 1), Mass_cell(1, 2), 1, nb_PVE_cells(i))./vol_beads_temp; %Initial concentration of each Pve cell present into the bead
        Mass_Cell_Ppu = normrnd(Mass_cell(2, 1), Mass_cell(2, 2), 1, nb_PPU_cells(i))./vol_beads_temp; %Initial concentration of each Pve cell present into the bead
        mat_y_0 = [Mass_Cell_Pve Mass_Cell_Ppu zeros(1, nb_PVE_cells(i)) zeros(1, nb_PPU_cells(i)) 0 0 mean_R_0_temp(1) mean_R_0_temp(2) 0 0 0]'; %Concentration in g/mL
        kappa_1_temp_Pve = normrnd(kappa_1_temp(1,i), k1_Pve(2), 1, nb_PVE_cells(i));
        kappa_3_temp_Pve = normrnd(kappa_3(1,i), k3_Pve(2), 1, nb_PVE_cells(i));
        kappa_1_temp_Ppu = normrnd(kappa_1_temp(2,i), k1_Ppu(2), 1, nb_PPU_cells(i));
        kappa_3_temp_Ppu = normrnd(kappa_3(2,i), k3_Ppu(2), 1, nb_PPU_cells(i));

        if strcmp(parameters_distr,'normal') % Single-cell growth parameters follow a normal distribution
            kappa_2_temp_Pve = normrnd(kappa_2(1,i), k2_Pve(2), 1, nb_PVE_cells(i));
            kappa_2_temp_Ppu = normrnd(kappa_2(2,i), k2_Ppu(2), 1, nb_PPU_cells(i));
            LT_Pve = normrnd(Lag_Time_Pve(1), Lag_Time_Pve(2),1, nb_PVE_cells(i));
            LT_Ppu = normrnd(Lag_Time_Ppu(1), Lag_Time_Ppu(2), 1, nb_PPU_cells(i));

        elseif strcmp(parameters_distr,'gamma') % Single-cell growth parameters follow a gamma distribution
            shape_mu_pv =  k2_Pve(1)^2/ k2_Pve(2);    % Shape parameter (alpha) for pve growth rate
            scale_mu_pv =  k2_Pve(2)/ k2_Pve(1);    % Scale parameter (teta)
            kappa_2_temp_Pve = gamrnd(shape_mu_pv, scale_mu_pv, [1, nb_PVE_cells(i)]);
            shape_mu_pp = k2_Ppu(1)^2/ k2_Ppu(2);     % Shape parameter (alpha)
            scale_mu_pp = k2_Ppu(2)/ k2_Ppu(1);     % Scale parameter (teta)
            kappa_2_temp_Ppu = gamrnd(shape_mu_pp, scale_mu_pp, [1, nb_PPU_cells(i)]);
            shape_lag_pv = Lag_Time_Pve(1)^2/Lag_Time_Pve(2);     % Shape parameter (alpha) for pve lag time
            scale_lag_pv = Lag_Time_Pve(2)/Lag_Time_Pve(1);     % Scale parameter (teta)
            LT_Pve = gamrnd(shape_lag_pv, scale_lag_pv, [1, nb_PVE_cells(i)]);
            shape_lag_pp = Lag_Time_Ppu(1)^2/Lag_Time_Ppu(2);     % Shape parameter (alpha)
            scale_lag_pp = Lag_Time_Ppu(2)/Lag_Time_Ppu(1);     % Scale parameter (teta)
            LT_Ppu = gamrnd(shape_lag_pp, scale_lag_pp, [1, nb_PPU_cells(i)]);
        end

        kappa_2_temp_Pve(rand(size(kappa_2_temp_Pve)) < probability_dead_pve) = 0;% Randomly attribute null growth rates to simulate growth impaired PVE cells
        kappa_2_temp_Ppu(rand(size(kappa_2_temp_Ppu)) < probability_dead_ppu) = 0;% Randomly attribute null growth rates to simulate growth impaired PPU cells
        kappa_PVE_mat = [kappa_1_temp_Pve; kappa_2_temp_Pve; kappa_3_temp_Pve; kappa_1_temp_Pve];
        kappa_PPU_mat = [kappa_1_temp_Ppu; kappa_2_temp_Ppu; kappa_3_temp_Ppu; kappa_1_temp_Ppu];
        nb_cells = [nb_PVE_cells(i), nb_PPU_cells(i)];
        sol = ode45(@(t, y) Fun_Monod_Mult_Cells(t, y, kappa_PVE_mat, kappa_PPU_mat, [Threshold(1); Threshold(2)], {{LT_Pve}; {LT_Ppu}}, nb_cells), tspan,  mat_y_0, opts_1);
        z = deval(sol, Time_step);
        %sum(z(1:4, end))/mean(Mass_cell) %number of cells/mL
        X_1 = round(((z(1:nb_cells(1), :) + z((sum(nb_cells) + 1):(sum(nb_cells) + nb_cells(1)), :))*vol_beads_temp)/Mass_cell(1)); %Conversion to obtain number of cells per bead
        X_2 = round((z((nb_cells(1) + 1):sum(nb_cells), :) + z((sum(nb_cells) + nb_cells(1) + 1):(2*sum(nb_cells)), :))*vol_beads_temp/Mass_cell(2)); %Conversion to obtain number of cells per bead
        Tab_output{i} = [Time_step; sum(X_1, 1); sum(X_2,1)];
        Tab_WastUsed{i} = [z(2*sum(nb_cells) + 5,:); z(2*sum(nb_cells) + 6,:)]; %[Use of waste W1 by S2; Use of waste W2 by S1]
%         plot(Time_step, z(1:nb_cells(1), :) + z((sum(nb_cells) + 1):(sum(nb_cells) + nb_cells(1)),:), Time_step, z((nb_cells(1) + 1):sum(nb_cells), :) + z((sum(nb_cells) + nb_cells(1) + 1):(2*sum(nb_cells)), :), Time_step, z((2*sum(nb_cells) + 1):(2*sum(nb_cells) + 3), :))
        %Saved data 
        Temp = Tab_output{i}';
        Temp_W = Tab_WastUsed{i}';
        n_temp = length(Temp(:,1));
        Pve_nb_Cells = Temp(:,2);
        Ppu_nb_Cells = Temp(:,3);
        PVE_fin_abs(i) = Temp(n_temp,2); %Final number of cells
        PPU_fin_abs(i) = Temp(n_temp,3); %Final number of cells
        W1_tot_used(i) = Temp_W(n_temp,1);
        W2_tot_used(i) = Temp_W(n_temp,2);
        Tot_nb_Cells_Evol(:,i) = Pve_nb_Cells + Ppu_nb_Cells; %Total value in OD (without noise)
        Props_sim_PVE(i) = Temp(n_temp,2)/(Temp(n_temp,3)+Temp(n_temp,2));
        Nb_Cells_Droplet(i,:) = [PVE_fin_abs(i) PPU_fin_abs(i)];
    end

    %     figure(num_fig)
%     boxplot(Props_sim_PVE, 'Labels',{'Sim'})
%     xlabel('Category')
%     ylabel('Proportions')
%     title('Boxplots final proportions Pve');
% 
%     num_fig = num_fig + 1;
%     figure(num_fig)
%     boxplot(PVE_fin_abs, 'Labels',{'Sim'})
%     xlabel('Category')
%     ylabel('Proportions')
%     title('Boxplots final abundances Pve (nb cells)');
%     num_fig = num_fig + 1;

%     figure(num_fig)
%     std_sim = std(Tot_nb_Cells_Evol, 0, 2);
%     mean_sim = mean(Tot_nb_Cells_Evol, 2);
%     errorbar(Time_step, mean_sim, std_sim,'r--o','MarkerSize',1,'LineWidth', 1,'MarkerEdgeColor','black','MarkerFaceColor','black');
%     
%     Abund_sim_PVE(1:nb_droplet) = PVE_fin_abs;
%     Abund_sim_PPU(1:nb_droplet) = PPU_fin_abs;
%     Fin_W1_used(1:nb_droplet) = W1_tot_used;
%     Fin_W2_used(1:nb_droplet) = W2_tot_used;
% 
%     %Waste used figures 
%     num_fig = num_fig + 1;
%     figure(num_fig)
%     bar(flip([mean(Fin_W2_used) mean(Fin_W1_used)]), 'stacked')
%     hold on 

%     if save_data == 1
%         FolderName = strcat(cd, '/Figures/');
%         FigList = findobj(allchild(0), 'flat', 'Type', 'figure');
%         for iFig = 1:length(FigList)
%             FigHandle = FigList(iFig);
%             FigName = num2str(get(FigHandle, 'Number'));
%             FigName = strcat(FolderName, FigName, Name_file);
%             set(0, 'CurrentFigure', FigHandle);
%             saveas(FigHandle, FigName, 'pdf');
%         end
%         save(DataFile)
%     end
end