clear;
close all;

%Model considered are of type: S + R -> P -> 2S, P <-> S + W, P -> S + F.
%Model with double waste, one (W) that can be reused by both species and the
%other (F) can't be reused.

% SET CURRENT FOLDER TO THE DIRECTORY OF THE SCRIPT
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n',resultPath);
% Find the index of the last '/'
lastSlashIndex = find(resultPath == '/', 1, 'last');
% Remove the last part after the last '/' (script file name)
main = resultPath(1:lastSlashIndex);
cd(main)


% Enter parameters to test:

Name_file = 'COWF'; %Name the produced data.
save_data = 1; %If save = 1, figures and tables are saved (.fig/.pdf or .xlsx) and overwrite the actual file of the same name.

% Probability to be a growth impaired cell
probability_dead_ppu = 0.15; % 0.15
probability_dead_pve = 0.15; % 0.15

% Parameters variance coefficients to test
% variance_range_pve = [0.000001:0.5:2.000001];
% variance_range_ppu = [0.000001:0.5:2.000001];
variance_range_pve = [1]; % no variance = 0.000001
variance_range_ppu = [1];

% Species growth parameters
pve_mumax = 0.26; % growth rates 0.26
ppu_mumax = 0.32; % 0.32
pve_lag = 4;      % lag times (hours) 4
ppu_lag = 0.7;    % 0.7

% Choose to change growth rates or lag times heterogeneity, or both
parameters_to_vary = {'mu_max', 'lag_time', 'both_parameters'};
tested_parameters = parameters_to_vary{3}; % SET ON 3 FOR THIS SIMULATION. Select between 1, 2 
% and 3 to respectively choose to play with the heterogeneity of the 
% maximum growth rates only, the lag times only, or both at the same time.


% Single-cell growth parameters distributions
distribution_par = {'gamma','normal'};
parameters_distr = distribution_par{1};

% Starting cells number distribution
distribution_possibilities = {'poisson', 'uniform'};
cell_distribution = distribution_possibilities{2}; % set on 1 or 2 to 
% respectively choose poisson or uniform distribution of founder cells 
% accross droplets

% number of replicate - increase the number of simulated droplets by the
% number of replicate wanted
n_replicate = 3;

% Droplets properties
droplet_rep = 500; 
nb_droplet = droplet_rep * n_replicate; %Number of droplets to simulate
volume_droplets = [35*10^(-9), 0];%[mean, std] normal distribution. %35 pL converted in g/mL. Volume droplets converted in mL. The concentration of resource per droplet corresponds to mean_R_0

% droplet/starting population size factor
drop_size = [1, 3.3333, 33.3333, 333.3333]; % droplet size factor (will multiply the input vol_droplets value)
pop_size = [3, 10, 100, 1000]; % starting population size

mean_R_0 = [2*2.4e-04; 0];%[6.67*10^(-3)*72/1000; 1*10*10^(-3)*48/1000]; %Initial resource concentration, correspond to 10mM of succinate
sigma_R_0 = 0; %Standard deviation for the resource concentration.

Time_step = 0:0.5:24; %Time step, 0:0.5:48 corresponds to the real measurement times of the experiment.

Mass_cell = [0.2*2.96e-13 0; 
    0.2*2.78e-13 0]; %[Pve, Ppu]Number of g per cell. The number of cell/mL is around 8e+08 vs 2.8e+09, perhaps this dry cell weight is overestimated?

%Concentration threshold. When the concentration of the reusable waste (W)
%is above this threshold, then the species i can use it.
Threshold = [1.400e-04; 2.8000e-05];%g/mL %[W_2 (produced by Ppu) by Pve), W_1 (produced by Pve) by Ppu)]

% Generate all combinations of PVE/PPU coefficient of variations for selected
% growth kinetics parameters
[VarPve, VarPpu] = meshgrid(variance_range_pve, variance_range_ppu);
pairwise_combinations = [VarPve(:), VarPpu(:)];
% Convert to table
table_combinations = array2table(pairwise_combinations, 'VariableNames', {'PVE', 'PPU'});
% Create an empty structure
%struct_combinations = struct('PVE', [], 'PPU', [], 'Nb_Cells_in_Droplets', []);

for j = 1:3%length(drop_size)

    % display iteration pop size 
    pop_size(j)

    for i = 1:height(table_combinations)
        
        main_struct(j).population_size = pop_size(j);

        % display iteration loop
        i
        %
        mu_droplet = [ pop_size(j); pop_size(j) ]; %Mean number of cells per droplet [PVE;PPU]
        vol_droplets = [volume_droplets(1) * drop_size(j), 0] ; % scale initial droplets' volume
        % Fill in the structure - Here we don't change variation
        main_struct(j).cell_nb(i).PVE = table_combinations{1,"PVE"};
        main_struct(j).cell_nb(i).PPU = table_combinations{1,"PPU"};

        % variability coefficients - change these values to increase or decrease
        % all parameters variability.
        cpv = main_struct(j).cell_nb(i).PVE; % PVE - cpv=1 -> no change in parameters variability; cpv>1 or <1 -> respectively increased or decreased variability
        cpp = main_struct(j).cell_nb(i).PPU; % PPU

        if strcmp(tested_parameters ,'mu_max')
            %Pve values
            k1_Pve = [2e05, 0]; %table_Pve.LN_k1; %kappa_1, uptake rate
            if strcmp(parameters_distr, 'gamma')
                k2_Pve = [pve_mumax, cpv*0.0075];
            elseif strcmp(parameters_distr, 'normal')
                k2_Pve = [pve_mumax, cpv*(pve_mumax/10)]; %table_Pve.LN_k2; %Mu_max
            end
            k3_Pve = [1.1, 0]; %table_Pve.LN_k2; %kappa_3 kappa_2/(kappa_2 + kappa_3) = yield

            %Ppu values
            k1_Ppu = [2e05, 0]; %table_Ppu.LN_k1; %kappa_1, uptake rate
            if strcmp(parameters_distr, 'gamma')
                k2_Ppu = [ppu_mumax, cpp*0.0062];
            elseif strcmp(parameters_distr, 'normal')
                k2_Ppu = [ppu_mumax, cpp*(ppu_mumax/10)]; %table_Ppu.LN_k2; %Mu_max
            end
            k3_Ppu = [1.5, 0]; %table_Pve.LN_k2; %kappa_3 kappa_2/(kappa_2 + kappa_3) = yield

            % Lag times
            if strcmp(parameters_distr, 'gamma')
                Lag_Time_Pve = [pve_lag, 3.26]; %Lag time in hours following a normal distribution
                Lag_Time_Ppu = [ppu_lag, 4.04]; %Lag time in hours following a normal distribution
            elseif strcmp(parameters_distr, 'normal')
                Lag_Time_Pve = [pve_lag, (pve_lag/10)]; %Lag time in hours following a normal distribution
                Lag_Time_Ppu = [ppu_lag, (ppu_lag/10)]; %Lag time in hours following a normal distribution
            end

        end

        if strcmp(tested_parameters ,'lag_time')
            %Pve values
            k1_Pve = [2e05, 0]; %table_Pve.LN_k1; %kappa_1, uptake rate
            if strcmp(parameters_distr, 'gamma')
                k2_Pve = [pve_mumax, 0.0075];
            elseif strcmp(parameters_distr, 'normal')
                k2_Pve = [pve_mumax, (pve_mumax/10)]; %table_Pve.LN_k2; %Mu_max
            end
            k3_Pve = [1.1, 0]; %table_Pve.LN_k2; %kappa_3 kappa_2/(kappa_2 + kappa_3) = yield
            %Ppu values
            k1_Ppu = [2e05, 0]; %table_Ppu.LN_k1; %kappa_1, uptake rate
            if strcmp(parameters_distr, 'gamma')
                k2_Ppu = [ppu_mumax, 0.0062];
            elseif strcmp(parameters_distr, 'normal')
                k2_Ppu = [ppu_mumax, (ppu_mumax/10)]; %table_Ppu.LN_k2; %Mu_max
            end
            k3_Ppu = [1.5, 0]; %table_Pve.LN_k2; %kappa_3 kappa_2/(kappa_2 + kappa_3) = yield

            % Lag times
            if strcmp(parameters_distr, 'gamma')
                Lag_Time_Pve = [pve_lag, cpv*3.26]; %Lag time in hours following a normal distribution
                Lag_Time_Ppu = [ppu_lag, cpp*4.04]; %Lag time in hours following a normal distribution
            elseif strcmp(parameters_distr, 'normal')
                Lag_Time_Pve = [pve_lag, cpv*(pve_lag/10)]; %Lag time in hours following a normal distribution
                Lag_Time_Ppu = [ppu_lag, cpp*(ppu_lag/10)]; %Lag time in hours following a normal distribution
            end


        end

        if strcmp(tested_parameters ,'both_parameters')
            %Pve values
            k1_Pve = [2e05, 0]; %table_Pve.LN_k1; %kappa_1, uptake rate
            if strcmp(parameters_distr, 'gamma')
                k2_Pve = [pve_mumax, cpv*0.0075];
            elseif strcmp(parameters_distr, 'normal')
                k2_Pve = [pve_mumax, cpv*(pve_mumax/10)]; %table_Pve.LN_k2; %Mu_max
            end
            k3_Pve = [1.1, 0]; %table_Pve.LN_k2; %kappa_3 kappa_2/(kappa_2 + kappa_3) = yield
            %Ppu values
            k1_Ppu = [2e05, 0]; %table_Ppu.LN_k1; %kappa_1, uptake rate
            if strcmp(parameters_distr, 'gamma')
                k2_Ppu = [ppu_mumax, cpp*0.0062];
            elseif strcmp(parameters_distr, 'normal')
                k2_Ppu = [ppu_mumax, cpp*(ppu_mumax/10)]; %table_Ppu.LN_k2; %Mu_max
            end
            k3_Ppu = [1.5, 0]; %table_Pve.LN_k2; %kappa_3 kappa_2/(kappa_2 + kappa_3) = yield

            % Lag times
            if strcmp(parameters_distr, 'gamma')
                Lag_Time_Pve = [pve_lag, cpv*3.26]; %Lag time in hours following a normal distribution
                Lag_Time_Ppu = [ppu_lag, cpp*4.04]; %Lag time in hours following a normal distribution
            elseif strcmp(parameters_distr, 'normal')
                Lag_Time_Pve = [pve_lag, cpv*(pve_lag/10)]; %Lag time in hours following a normal distribution
                Lag_Time_Ppu = [ppu_lag, cpp*(ppu_lag/10)]; %Lag time in hours following a normal distribution
            end

        end

        %% Run model

        Name_Model = @Fun_Monod; %@Fun_With_Int; @Fun_With_Int_W1_W2_F %Type of the function to test. Description in the corresponding function file.

        [Tot_Gram_Evol, Abund_sim_PVE, Abuind_sim_PPU, Props_sim_PVE, Nb_Cells_Droplet] = Main_Fun_Droplets_Mult_Cells(parameters_distr, cell_distribution, probability_dead_ppu, probability_dead_pve, vol_droplets, Mass_cell, nb_droplet, mu_droplet, k1_Pve, k2_Pve, k3_Pve, k1_Ppu, k2_Ppu, k3_Ppu, Threshold, Lag_Time_Pve, Lag_Time_Ppu, mean_R_0, sigma_R_0, Time_step, Name_file, save_data)

        main_struct(j).cell_nb(i).Nb_Cells_in_Droplets = Nb_Cells_Droplet;

    end

end
%% Convert the number of cells into biomass and estimate the dominance score of PVE

for j = 1:length(main_struct)

    for i = 1:length(main_struct(j).cell_nb)

        main_struct(j).cell_nb(i).biomass = main_struct(j).cell_nb(i).Nb_Cells_in_Droplets;
        main_struct(j).cell_nb(i).biomass(:, 1) = main_struct(j).cell_nb(i).biomass(:, 1) * Mass_cell(1);
        main_struct(j).cell_nb(i).biomass(:, 2) = main_struct(j).cell_nb(i).biomass(:, 2) * Mass_cell(2);

        % find index of co-culture droplets where PVE is dominant
        idx = main_struct(j).cell_nb(i).biomass(:, 1) > main_struct(j).cell_nb(i).biomass(:, 2);
        newTbl = array2table(main_struct(j).cell_nb(i).biomass(idx,:), 'VariableNames', {'PVE_biomass', 'PPU_biomass'});
        newTbl = newTbl(newTbl.PPU_biomass ~= 0, :);
        nb_dominant_pve = height(newTbl);
        % find index of co-culture droplets
        idx2 = find(main_struct(j).cell_nb(i).biomass(:, 1) > 0 & main_struct(j).cell_nb(i).biomass(:, 2) > 0);
        nb_coculture_droplets = length(idx2);
        % Calculate PVE dominance score
        pve_dominance = nb_dominant_pve / nb_coculture_droplets;

        % Save in the structure
        main_struct(j).cell_nb(i).nb_coculture_droplets = nb_coculture_droplets;
        main_struct(j).cell_nb(i).nb_dominantpve_droplets = nb_dominant_pve;
        main_struct(j).cell_nb(i).pve_dominance_score = pve_dominance;

    end

end
%% Split the simulated obtained biomass into different replicate data-set,
% then calculate a per-replicate PVE dominance score.

% Create new fields for replicates
replicate_fields = cell(n_replicate, 1);
replicate_names = cell(n_replicate, 1);
for i = 1:n_replicate
    replicate_fields{i} = ['replicate' num2str(i)];
    replicate_names{i} = ['Replicate ' num2str(i)];
end

% Iterate over each row of the structure
for j = 1:numel(main_struct)

    for i = 1:numel(main_struct(j).cell_nb)
        % Get the 'biomass' matrix for the current row
        biomass_matrix = main_struct(j).cell_nb(i).biomass;

        % Randomly shuffle the rows of the matrix
        shuffled_matrix = biomass_matrix(randperm(size(biomass_matrix, 1)), :);

        % Split the shuffled matrix into replicates
        n = size(shuffled_matrix, 1);
        split_points = round(linspace(0, n, n_replicate+1));

        PVE_dom_replicate = [];

        % Assign the rows to the respective replicate fields
        for z = 1:n_replicate
            replicate_field = replicate_fields{z};
            start_idx = split_points(z) + 1;
            end_idx = split_points(z+1);
            main_struct(j).cell_nb(i).(replicate_field) = shuffled_matrix(start_idx:end_idx, :);

            % calculate PVE-dominance score per replicate
            rep_droplets = shuffled_matrix(start_idx:end_idx, :);
            % find index of co-culture droplets where PVE is dominant
            idx = rep_droplets(:,1) > rep_droplets(:,2);
            newTbl = array2table(rep_droplets(idx,:), 'VariableNames', {'PVE_biomass', 'PPU_biomass'});
            newTbl = newTbl(newTbl.PPU_biomass ~= 0, :);
            nb_dominant_pve = height(newTbl);
            % find index of co-culture droplets
            idx2 = find(rep_droplets(:, 1) > 0 & rep_droplets(:, 2) > 0);
            nb_coculture_droplets = length(idx2);
            % Calculate PVE dominance score
            pve_dominance = nb_dominant_pve / nb_coculture_droplets;
            % save the per replicate PVE dominance score in the structure
            fiedName = ['pve_dominance_score_',(replicate_field)];
            main_struct(j).cell_nb(i).(fiedName) = pve_dominance;
            % Save PVE dominance score / replicate in a separate array
            PVE_dom_replicate{z} = pve_dominance;
        end
        main_struct(j).cell_nb(i).average_pve_dominance_score = mean([PVE_dom_replicate{:}]);
    end

end


%% Heatmap - PVE dominance score

% % Extract PVE and PPU values
% pve_values = unique([struct_combinations.PVE]);
% ppu_values = unique([struct_combinations.PPU]);
% 
% % Reverse the order of PVE values
% pve_values = flip(pve_values);
% 
% % Extract dominance scores from the structure
% dominance_scores = NaN(numel(pve_values), numel(ppu_values));
% for i = 1:numel(pve_values)
%     for j = 1:numel(ppu_values)
%         idx = find([struct_combinations.PVE] == pve_values(i) & [struct_combinations.PPU] == ppu_values(j));
%         if ~isempty(idx)
%             dominance_scores(i, j) = struct_combinations(idx).average_pve_dominance_score;
%         end
%     end
% end
% 
% % Create heatmap
% 
% if strcmp(tested_parameters ,'mu_max')
%     maintitle = 'Growth rates' ;
%     xlab = 'PPU growth rates - coefficient of variation';
%     ylab = 'PVE growth rates - coefficient of variation';
% end
% if strcmp(tested_parameters ,'lag_time')
%     maintitle = 'Lag times' ;
%     xlab = 'PPU lag times - coefficient of variation';
%     ylab = 'PVE lag times - coefficient of variation';
% end
% if strcmp(tested_parameters ,'both_parameters')
%     maintitle = 'Growth rates and lag times' ;
%     xlab = 'PPU growth parameters - coefficient of variation';
%     ylab = 'PVE growth parameters - coefficient of variation';
% end
% 
% % Create colormap and reverse it
% cmap = flip(colormap('pink')); % pink
% 
% figure;
% heatmap(ppu_values, pve_values, dominance_scores, 'ColorbarVisible', 'on', 'ColorLimits', [0.07, 0.21]);
% colormap(cmap);  % Set colormap - cmap
% title(maintitle);
% xlabel(xlab);
% ylabel(ylab);


%% Save the results

% Flatten the nested structures
flatCell = {};

for i = 1:length(main_struct)
    popsize_value = main_struct(i).population_size;
    cellnb_struct = main_struct(i).cell_nb;
    var_PVE = cellnb_struct.PVE;
    var_PPU = cellnb_struct.PPU;
    nb_coculture_droplets = cellnb_struct.nb_coculture_droplets;
    
    for j = 1:n_replicate
        biomass_PVE = cellnb_struct.(['replicate' num2str(j)])(:,1);
        biomass_PPU = cellnb_struct.(['replicate' num2str(j)])(:,2);
        repname = ['R' num2str(j)];

        for k = 1:numel(biomass_PVE)
            observation_PVE = biomass_PVE(k);
            observation_PPU = biomass_PPU(k);

            flatCell{end+1} = struct('population_size', popsize_value, 'var_PVE', var_PVE, 'var_PPU', var_PPU, ...
                'nb_coculture_droplets', nb_coculture_droplets, 'replicate', repname, 'biomass_PVE', observation_PVE, 'biomass_PPU', observation_PPU);
        end
    end
end

clear popsize_value cellnb_struct biomass_PVE biomass_PPU var_PVE var_PPU nb_coculture_droplets observation_PVE observation_PPU


% Convert flattened cell array into a structure
flatStruct = [flatCell{:}];
% Convert flattened structure into a table
tableData = struct2table(flatStruct);


if save_data == 0
    % do not save data
else

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
outputPath = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', outputPath);


% Specify the file name for the saved structure
fileName = strcat(num2str(droplet_rep),'x',num2str(n_replicate),'_', tested_parameters,'_',cell_distribution,'distribution_biggerdrop_main_struct_TEST.mat');

% Construct the full file path
result_path = strcat(outputPath,'results_plots/');
filePath = fullfile(outputPath,'results_plots', fileName);

% Save the main_struct structure to the specified file path
save(filePath, 'main_struct'); % save structure
writetable(tableData,fullfile(result_path,'/',strcat(cell_distribution,'_biggerdrop_table_results.csv')),'WriteRowNames',true); % save data table created from structure

end



