function dx = Fun_Monod_Mult_Cells(t, z, kappa_PVE, kappa_PPU, threshold, Lag_Time, nb_cells)
%Function with two wastes that can be reused
%z(1), dx_1: biomass bacterial species 1. z(2), dx_2: biomass bacterial
%species 2. z(3), dy_1: biomass complex. z(4), dy_2: biomass complex.
%z(5), dw_1 biomass waste produced by species 1 that can be used by species
%2. z(6), dw_2: biomass waste produced by species 2 that can be used by
%species 1. z(7), dr_1: biomass resource 1. z(8) dr_2: biomass resource 1.
% Model: S_i + R_i -> P_i -> 2S_i, P_i <-> S_i + W_i, S_j + W_i -> P_j.
% z(z<=0) = 0;
LT_1 = cell2mat(Lag_Time{1}); LT_2 = cell2mat(Lag_Time{2}); %Lag time, if there are lag times then LT_i > 0.
T_1 = 0;%(z(6) - threshold(1) > 0); %W_2 by Pve. 1 = Cross always active, 0 = no cross-feeding
T_2 = 0;%(z(5) - threshold(2) > 0); %W_1 by Ppu
ind_Pve = 1:nb_cells(1);
ind_Ppu = (nb_cells(1) + 1):sum(nb_cells);
ind_Pve_comp = (sum(nb_cells) + 1):(sum(nb_cells) + nb_cells(1));
ind_Ppu_comp = (sum(nb_cells) + nb_cells(1) + 1):(2*sum(nb_cells));
ind_Pve_waste = 2*sum(nb_cells) + 1;
ind_Ppu_waste = 2*sum(nb_cells) + 2;
ind_Res = 2*sum(nb_cells) + 3;
dx_1 = (2*kappa_PVE(2,:) + kappa_PVE(3,:))'.*z(ind_Pve_comp) - kappa_PVE(1,:)'.*(z(ind_Pve)*z(ind_Res)) - T_1*kappa_PVE(4,:)'.*z(ind_Pve)*z(ind_Ppu_waste);
dx_2 = (2*kappa_PPU(2,:) + kappa_PPU(3,:))'.*z(ind_Ppu_comp) - kappa_PPU(1,:)'.*(z(ind_Ppu)*z(ind_Res)) - T_2*kappa_PPU(4,:)'.*z(ind_Ppu)*z(ind_Pve_waste);
dy_1 = -(kappa_PVE(2,:) + kappa_PVE(3,:))'.*z(ind_Pve_comp) + kappa_PVE(1,:)'.*(z(ind_Pve)*z(ind_Res)) + T_1*kappa_PVE(4,:)'.*z(ind_Pve)*z(ind_Ppu_waste);
dy_2 = -(kappa_PPU(2,:) + kappa_PPU(3,:))'.*z(ind_Ppu_comp) + kappa_PPU(1,:)'.*(z(ind_Ppu)*z(ind_Res)) + T_2*kappa_PPU(4,:)'.*z(ind_Ppu)*z(ind_Pve_waste);
dw_1 = sum((t >= LT_1)'.*kappa_PVE(3,:)'.*z(ind_Pve_comp)) - sum((t >= LT_2)'.*(T_2*kappa_PPU(4,:)'.*z(ind_Ppu)*z(ind_Pve_waste)));
dw_2 = sum((t >= LT_2)'.*kappa_PPU(3,:)'.*z(ind_Ppu_comp)) - sum((t >= LT_1)'.*(T_1*kappa_PVE(4,:)'.*z(ind_Pve)*z(ind_Ppu_waste)));
du_1 = sum(T_2*kappa_PPU(4,:)'.*z(ind_Ppu)*z(ind_Pve_waste)); %Used by PPU
du_2 = sum(T_1*kappa_PVE(4,:)'.*z(ind_Pve)*z(ind_Ppu_waste)); %Used by PVE
dr_1 = -sum((t >= LT_1)'.*kappa_PVE(1,:)'.*(z(ind_Pve)*z(ind_Res))) - sum((t >= LT_2)'.*kappa_PPU(1,:)'.*(z(ind_Ppu)*z(ind_Res)));
dx = [(t >= LT_1)'.*dx_1; (t >= LT_2)'.*dx_2; (t >= LT_1)'.*dy_1; (t >= LT_2)'.*dy_2; dw_1;...
    dw_2; dr_1; 0; du_1; du_2; 0];


