

# Associate well names to each well ID
for (n in well_names$Well.ID) {
  fc_table[which(fc_table$Well.ID == n), 'well_name'] <- well_names[which(well_names$Well.ID == n),'well.name']
}

# Post processing
droplet_plate <- fc_table %>% 
  separate(well_name, c('Culture', 'Condition','BioRep', 'TechRep','FCcountingRep','DilutionFactor')) %>% 
  mutate(NumberSpecies = case_when(Condition == "PPU"|Condition == "PVE" ~ "mono" , Condition == "MIX" ~ "mix" )) %>%
  mutate(VolumeAnalysed_µl = 20) # add a variable for the volume analysed in flow cytometry (µl) - 20µl for most of the wells
droplet_plate$DilutionFactor <- as.numeric(droplet_plate$DilutionFactor)


unique(droplet_plate$DilutionFactor)

# Cell concentrations in fused droplets
droplet_cell_concentration <- droplet_plate %>% 
  filter(Culture == 'droplets')  %>% 
  mutate(CellConcentration.GFP = case_when(
    # PPU (gfp channel) - R1
    BioRep== 'R1' &Condition=='PPU' ~ (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP1),
    # R2
    BioRep== 'R2' &Condition=='PPU' ~ (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP2),
    #R3
    BioRep== 'R3' &Condition=='PPU' ~ (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP3),
    
    BioRep== 'R1' &Condition=='MIX' ~ (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix1),
    # R2
    BioRep== 'R2' &Condition=='MIX' ~ (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix2),
    #R3
    BioRep== 'R3' &Condition=='MIX' ~ (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix3)
  )) %>% 
  
  mutate(CellConcentration.MCH = case_when(
       #250 = vol PBS in tube 
       #80 = initial vol droplets
    # PVE (mCherry channel) - R1
    BioRep== 'R1' &Condition=='PVE' ~ (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV1),
    # R2
    BioRep== 'R2' &Condition=='PVE' ~ (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV2),
    # R3
    BioRep== 'R3' &Condition=='PVE' ~ (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV3),
    
    BioRep== 'R1' &Condition=='MIX' ~ (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix1),
    # R2
    BioRep== 'R2' &Condition=='MIX' ~ (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix2),
    # R3
    BioRep== 'R3' &Condition=='MIX' ~ (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix3)
  ))

# in previous lines: adjust the concentration of Pve and Ppu based on the proportion of non empty droplets measured from droplets images of all replicates


### same for plate samples
plate_cell_concentration <- droplet_plate %>% 
  filter(Culture == 'plate') %>% 
  mutate(CellConcentration.GFP = (GFP.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)) %>% 
  mutate(CellConcentration.MCH = (mCherry.Count/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor))

### Bind droplet and plate cell concentration tables
cell_conc <- rbind(droplet_cell_concentration, plate_cell_concentration)


