

library(tidyverse)
library(ggpubr)
library(dplyr)


### Add 'mono/mix' column
DropletsF2 <- DropletsF %>% 
  mutate(NbSpecies = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 | Fluo1Sum > 0 & Fluo2Sum == 0 ~ "mono", 
    Fluo1Sum == 0 & Fluo2Sum == 0 ~ "medium",
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "mix"
  )) %>% 
  ### Add 'Species' column
  mutate(Species = case_when(
    Fluo1Sum == 0 & Fluo2Sum > 0 ~ 'PPU',
    Fluo1Sum > 0 & Fluo2Sum == 0 ~ 'PVE',
    Fluo1Sum > 0 & Fluo2Sum > 0 ~ "MIX"
  )) %>%
  mutate(factor = fct_relevel(NbSpecies, "mono", "mix","medium")) # Add a 'factor' column to plot mono-culture before mix-culture
DropletsF <- DropletsF2


# R1
# PPU mono
nedPP_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Condition == 'PPU', Fluo2Sum > 0)) # non empty PPU droplet
adPP_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Condition == 'PPU')) # all droplets
ratio_non_emptyPP1 <- nedPP_24/adPP_24 # Proportion of non empty droplets in PPU monoculture
# PVE mono
nedPV_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Condition == 'PVE', Fluo1Sum > 0))
adPV_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Condition == 'PVE'))
ratio_non_emptyPV1 <- nedPV_24/adPV_24 # Proportion of non empty droplets in PVE monoculture

# PPU mixed culture
nedPPmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Fluo2Sum > 0, Condition == 'MIX' ));nedPPmix_24
adPVPPmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Condition == 'MIX'));adPVPPmix_24
ratio_non_emptyPPmix1 <- nedPPmix_24/adPVPPmix_24;ratio_non_emptyPPmix1 # Proportion of non empty droplets
# PVE mixed culture
nedPVmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R1', Timepoint == 'T24', Fluo1Sum > 0, Condition == 'MIX' ));nedPVmix_24
ratio_non_emptyPVmix1 <- nedPVmix_24/adPVPPmix_24;ratio_non_emptyPVmix1 # Proportion of non empty droplets

#R2
# PPU mono
nedPP_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Condition == 'PPU', Fluo2Sum > 0)) # non empty PPU droplet
adPP_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Condition == 'PPU')) # all droplets
ratio_non_emptyPP2 <- nedPP_24/adPP_24 # Proportion of non empty droplets in PPU monoculture
# PVE mono
nedPV_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Condition == 'PVE', Fluo1Sum > 0))
adPV_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Condition == 'PVE'))
ratio_non_emptyPV2 <- nedPV_24/adPV_24 # Proportion of non empty droplets in PVE monoculture

# PPU mixed culture
nedPPmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Fluo2Sum > 0, Condition == 'MIX' ))
adPVPPmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Condition == 'MIX'))
ratio_non_emptyPPmix2 <- nedPPmix_24/adPVPPmix_24 # Proportion of non empty droplets
# PVE mixed culture
nedPVmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R2', Timepoint == 'T24', Fluo1Sum > 0, Condition == 'MIX'))
ratio_non_emptyPVmix2 <- nedPVmix_24/adPVPPmix_24 # Proportion of non empty droplets

#R3
# PPU mono
nedPP_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Condition == 'PPU', Fluo2Sum > 0)) # non empty PPU droplet
adPP_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Condition == 'PPU')) # all droplets
ratio_non_emptyPP3 <- nedPP_24/adPP_24 # Proportion of non empty droplets in PPU monoculture
# PVE mono
nedPV_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Condition == 'PVE', Fluo1Sum > 0))
adPV_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Condition == 'PVE'))
ratio_non_emptyPV3 <- nedPV_24/adPV_24 # Proportion of non empty droplets in PVE monoculture

# PPU mixed culture
nedPPmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Fluo2Sum > 0, Condition == 'MIX' ))
adPVPPmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Condition == 'MIX'))
ratio_non_emptyPPmix3 <- nedPPmix_24/adPVPPmix_24 # Proportion of non empty droplets
# PVE mixed culture
nedPVmix_24 <- nrow(DropletsF %>% filter(BiologicalRep == 'R3', Timepoint == 'T24', Fluo1Sum > 0, Condition == 'MIX' ))
ratio_non_emptyPVmix3 <- nedPVmix_24/adPVPPmix_24 # Proportion of non empty droplets




